<?php
namespace AustraliaPost\Extensions\Business\API\Wrapper;

class Address {

	private $name;
	private $lines = [];
	private $suburb;
	private $state;
	private $postcode;
	private $country;
	private $phone;
	private $email;
	private $delivery_instructions = '';

	public static function create( $address )
	{
		$instance = new self();
		$instance->setName($address['first_name'] . ' ' . $address['last_name']);
		$instance->setPostcode($address['postcode']);
		$instance->setSuburb($address['city']);
		$instance->addLine($address['address_1']);
		$instance->addLine($address['address_2']);
		$instance->setState($address['state']);
		$instance->setCountry($address['country']);
		$instance->setEmail($address['email']);

		if (isset($address['delivery_instructions'])) {
			$instance->setDeliveryInstructions($address['delivery_instructions']);
		}

		return $instance;
	}

	/**
	 * @return mixed
	 */
	public function getName() {
		return $this->name;
	}

	/**
	 * @param mixed $name
	 */
	public function setName( $name ) {
		$this->name = $name;
	}

	/**
	 * @return array
	 */
	public function getLines() {
		return $this->lines;
	}

	/**
	 * @param array $lines
	 */
	public function addLine( $line ) {
		$this->lines[] = $line;
	}

	/**
	 * @return mixed
	 */
	public function getSuburb() {
		return $this->suburb;
	}

	/**
	 * @param mixed $suburb
	 */
	public function setSuburb( $suburb ) {
		$this->suburb = $suburb;
	}

	/**
	 * @return mixed
	 */
	public function getState() {
		return $this->state;
	}

	/**
	 * @param mixed $state
	 */
	public function setState( $state ) {
		$this->state = $state;
	}

	/**
	 * @return mixed
	 */
	public function getPostcode() {
		return $this->postcode;
	}

	/**
	 * @param mixed $postcode
	 */
	public function setPostcode( $postcode ) {
		$this->postcode = $postcode;
	}

	/**
	 * @return mixed
	 */
	public function getPhone() {
		return $this->phone;
	}

	/**
	 * @param mixed $phone
	 */
	public function setPhone( $phone ) {
		$this->phone = $phone;
	}

	/**
	 * @return mixed
	 */
	public function getEmail() {
		return $this->email;
	}

	/**
	 * @param mixed $email
	 */
	public function setEmail( $email ) {
		$this->email = $email;
	}

	public function getPayLoad() {
		$payload = [
			'name'  => $this->getName(),
			'lines'  => $this->getLines(),
			'suburb'  => $this->getSuburb(),
			'state'  => $this->getState(),
			'postcode'  => $this->getPostcode(),
			'country'  => $this->getCountry(),
			'phone'  => $this->getPhone(),
			'email'  => $this->getEmail(),
		];

		if ($this->getDeliveryInstructions() !== '') {
			$payload['delivery_instructions'] = $this->getDeliveryInstructions();
		}

		return $payload;
	}

	/**
	 * @return mixed
	 */
	public function getCountry() {
		return $this->country;
	}

	/**
	 * @param mixed $country
	 */
	public function setCountry( $country ) {
		$this->country = $country;
	}

	/**
	 * @return mixed
	 */
	public function getDeliveryInstructions()
	{
		return $this->delivery_instructions;
	}

	/**
	 * @param mixed $delivery_instructions
	 *
	 * @return Address
	 */
	public function setDeliveryInstructions( $delivery_instructions )
	{
		if (strlen($delivery_instructions) < 128) {
			$this->delivery_instructions = $delivery_instructions;
			return $this;
		}


		$this->delivery_instructions = substr($delivery_instructions, 0, 127);

		return $this;
	}


}
